@@ -29,6 +29,14 @@ cat("\n Contrast matrix on the level of the logit link: \n")
 
 print(object$cmat, digits=digits)
 
+if(object$dist=="MVN")
+{
+cat("\n The estimated correlation matrix of the contrasts is: \n")
+
+print(object$corrmat, digits=digits)
+
+}
+
 cat("\n")
 
 print(object, digits=digits)
